summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kgloballedgerview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kgloballedgerview.h')
-rw-r--r--kmymoney2/views/kgloballedgerview.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kmymoney2/views/kgloballedgerview.h b/kmymoney2/views/kgloballedgerview.h
index 0d782ab..a91b557 100644
--- a/kmymoney2/views/kgloballedgerview.h
+++ b/kmymoney2/views/kgloballedgerview.h
@@ -68,10 +68,10 @@ class MousePressFilter : public TQObject
Q_OBJECT
TQ_OBJECT
public:
- MousePressFilter(TQWidget* tqparent = 0, const char* name = 0);
+ MousePressFilter(TQWidget* parent = 0, const char* name = 0);
/**
* Add widget @p w to the list of possible tqparent objects. See eventFilter() how
* they will be used.
*/
void addWidget(TQWidget* w);
@@ -96,14 +96,14 @@ public slots:
protected:
/**
* This method checks if the widget @p child is a child of
* the widget @p tqparent and returns either @a true or @a false.
*
* @param child pointer to child widget
* @param tqparent pointer to tqparent widget
* @retval true @p child points to widget which has @p tqparent as tqparent or grand-tqparent
* @retval false @p child points to a widget which is not related to @p tqparent
*/
- bool isChildOf(TQWidget* child, TQWidget* tqparent);
+ bool isChildOf(TQWidget* child, TQWidget* parent);
/**
* Reimplemented from base class. Sends out the mousePressedOnExternalWidget() signal
@@ -133,7 +133,7 @@ class KGlobalLedgerView : public KMyMoneyViewBase
Q_OBJECT
TQ_OBJECT
public:
- KGlobalLedgerView(TQWidget *tqparent=0, const char *name=0);
+ KGlobalLedgerView(TQWidget *parent=0, const char *name=0);
~KGlobalLedgerView();
/**
@@ -68,10 +68,10 @@ class MousePressFilter : public TQObject
/**
- * Add widget @p w to the list of possible tqparent objects. See eventFilter() how
+ * Add widget @p w to the list of possible parent objects. See eventFilter() how
* they will be used.
*/
@@ -96,14 +96,14 @@ public slots:
/**
* This method checks if the widget @p child is a child of
- * the widget @p tqparent and returns either @a true or @a false.
+ * the widget @p parent and returns either @a true or @a false.
*
* @param child pointer to child widget
@@ -96,14 +96,14 @@ public slots:
*
* @param child pointer to child widget
- * @param tqparent pointer to tqparent widget
- * @retval true @p child points to widget which has @p tqparent as tqparent or grand-tqparent
- * @retval false @p child points to a widget which is not related to @p tqparent
+ * @param parent pointer to parent widget
+ * @retval true @p child points to widget which has @p parent as parent or grand-parent
+ * @retval false @p child points to a widget which is not related to @p parent
*/